# -*- coding: utf-8 -*-

DATA_SET = [
    (
        [u"* first line",
         u""],
        [("ls",
          [u"* first line",
           u""],
          u""),
         1]
    ),
    (
        [u"* first line"],
        [("ls",
          [u"* first line"],
          u""),
         1]
    ),
    (
        [u"* first line",
         u"* second line",
         u""],
        [("ls",
          [u"* first line",
           u"* second line",
           u""],
          u""),
         2]
    ),
    (
        [u"* first line",
         u"* second line"],
        [("ls",
          [u"* first line",
           u"* second line"],
          u""),
         1]
    ),
    (
        [u"* first line",
         u"  * second line",
         u""],
        [("ls",
          [u"* first line",
           u"  * second line",
           u""],
          u""),
         2]
    ),
    (
        [u"* first line",
         u"",
         u"  * second line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  * second line",
           u""],
          u""),
         3]
    ),
    (
        [u"* first line",
         u"  * second line",
         u"    * third line",
         u""],
        [("ls",
          [u"* first line",
           u"  * second line",
           u"    * third line",
           u""],
          u""),
         3]
    ),
    (
        [u"* first line",
         u"  * second line",
         u"    sub line",
         u"    * third line",
         u""],
        [("ls",
          [u"* first line",
           u"  * second line",
           u"    sub line",
           u"    * third line",
           u""],
          u""),
         4]
    ),
    (
        [u"* first line",
         u"",
         u"  * second line",
         u"",
         u"    * third line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  * second line",
           u"",
           u"    * third line",
           u""],
          u""),
         5]
    ),
    (
        [u"* first line",
         u"",
         u"  * second line",
         u"    sub line",
         u"",
         u"    * third line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  * second line",
           u"    sub line",
           u"",
           u"    * third line",
           u""],
          u""),
         6]
    ),
    (
        [u"* first line",
         u"",
         u"  * second line",
         u"",
         u"",
         u"    * third line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  * second line",
           u""],
          u""),
         3]
    ),
    (
        [u"* first line",
         u"",
         u"  - second line",
         u"  - third line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  - second line",
           u"  - third line",
           u""],
          u""),
         4]
    ),
    (
        [u"* first line",
         u"",
         u"  - second line",
         u"",
         u"    - third line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  - second line",
           u"",
           u"    - third line",
           u""],
          u""),
         5]
    ),
    (
        [u"* first line",
         u"",
         u"  - second line",
         u"",
         u"    * third line",
         u"",
         u"  - fourth line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  - second line",
           u"",
           u"    * third line",
           u"",
           u"  - fourth line",
           u""],
          u""),
         7]
    ),
    (
        [u"* first line",
         u"",
         u"  - second line",
         u"",
         u"    * third line",
         u"    * fourth line",
         u"",
         u"  - fifth line",
         u""],
        [("ls",
          [u"* first line",
           u"",
           u"  - second line",
           u"",
           u"    * third line",
           u"    * fourth line",
           u"",
           u"  - fifth line",
           u""],
          u""),
         8]
    ),
]
